@@ -1,19 +1,27 @@
+# dnscrypt ---------
 #! /bin/sh
 
+if [ -z "$NDK_PLATFORM" ]; then
+  export NDK_PLATFORM="android-19"
+  export NDK_PLATFORM_COMPAT="${NDK_PLATFORM_COMPAT:-android-16}"
+else
+  export NDK_PLATFORM_COMPAT="${NDK_PLATFORM_COMPAT:-${NDK_PLATFORM}}"
+fi
+
 if [ -z "$ANDROID_NDK_HOME" ]; then
-    echo "You should probably set ANDROID_NDK_HOME to the directory containing"
-    echo "the Android NDK"
-    exit
+  echo "You should probably set ANDROID_NDK_HOME to the directory containing"
+  echo "the Android NDK"
+  exit
 fi
 
 if [ ! -f ./configure ]; then
-	echo "Can't find ./configure. Wrong directory or haven't run autogen.sh?"
-	exit 1
+  echo "Can't find ./configure. Wrong directory or haven't run autogen.sh?"
+  exit 1
 fi
 
 if [ "x$TARGET_ARCH" = 'x' ] || [ "x$ARCH" = 'x' ] || [ "x$HOST_COMPILER" = 'x' ]; then
-    echo "You shouldn't use android-build.sh directly, use android-[arch].sh instead"
-    exit 1
+  echo "You shouldn't use android-build.sh directly, use android-[arch].sh instead"
+  exit 1
 fi
 
 export MAKE_TOOLCHAIN="${ANDROID_NDK_HOME}/build/tools/make-standalone-toolchain.sh"
@@ -63,7 +71,7 @@ rm -fr "${PREFIX}/system/include" "${PREFIX}/system/share" "${PREFIX}/system/man
 mkdir -p "${PREFIX}/system/lib" && \
 cp "${SODIUM_ANDROID_PREFIX}/lib/libsodium.so" "${PREFIX}/system/lib" && \
 (cd dist-build/android-files && tar cpf - *) | (cd "$PREFIX" && tar xpvf -) &&
-(cd "$PREFIX"; zip -9 -r "${PREFIX}.zip" *) && \
+(cd "$PREFIX"; 7z a -tzip -mx=9 -r "${PREFIX}.zip" *) && \
 echo "dnscrypt-proxy has been installed here:" && \
 echo "${PREFIX}" && \
 echo "The dnscrypt-proxy ZIP file has been placed here:" && \
