@@ -1,18 +1,23 @@
 #! /bin/sh
 
-export CFLAGS="-Os -m32 -march=pentium2 -mtune=nocona"
+export CFLAGS="-Os -m32 -march=pentium3 -mtune=core2"
+export LDFLAGS="-march=pentium3"
 export PREFIX="$(pwd)/dnscrypt-proxy-win32"
 export MINGW_PREFIX='/mingw32'
 export SODIUM_PREFIX='/tmp/libsodium-win32'
 
-export CPPFLAGS="-I${SODIUM_PREFIX}/include"
-export LDFLAGS="-L${SODIUM_PREFIX}/lib"
+export CPPFLAGS="${CPPFLAGS} -I${SODIUM_PREFIX}/include"
+export LDFLAGS="${LDFLAGS} -L${SODIUM_PREFIX}/lib"
+
+if [ ! -d "$SODIUM_PREFIX" ]; then
+  echo "WARNING: [$SODIUM_PREFIX] not found, compiling against system libsodium" >&2
+  sleep 10
+fi
 
 ./configure --prefix="$PREFIX" --exec-prefix="$PREFIX" \
   --host=i686-w64-mingw32 \
   --bindir="$PREFIX" \
   --sbindir="$PREFIX" \
-  --enable-plugins \
   --with-included-ltdl && \
 make install
 
@@ -27,7 +32,7 @@ cp "${MINGW_PREFIX}/bin/libldns-1.dll" "${PREFIX}/"
 cp "${SODIUM_PREFIX}/bin/libsodium-18.dll" "${PREFIX}/"
 
 nm "${MINGW_PREFIX}/bin/libldns-1.dll" | \
-  fgrep -i libeay &&
+  fgrep -i libeay > /dev/null &&
   cp "${MINGW_PREFIX}/bin/"libeay*.dll "${PREFIX}/"
 
 cp dnscrypt-resolvers.csv "${PREFIX}/"
