@@ -29,14 +29,14 @@ dcplugin_init(DCPlugin * const dcplugin, int argc, char *argv[])
 DCPluginSyncFilterResult
 dcplugin_sync_pre_filter(DCPlugin *dcplugin, DCPluginDNSPacket *dcp_packet)
 {
-    ldns_pkt                 *packet;
+    ldns_pkt                 *packet = NULL;
     ldns_rr_list             *questions;
     uint8_t                  *wire_data;
     DCPluginSyncFilterResult  result = DCP_SYNC_FILTER_RESULT_OK;
 
     wire_data = dcplugin_get_wire_data(dcp_packet);
-    ldns_wire2pkt(&packet, wire_data, dcplugin_get_wire_data_len(dcp_packet));
-    if (packet == NULL) {
+    if (ldns_wire2pkt(&packet, wire_data, dcplugin_get_wire_data_len(dcp_packet))
+        != LDNS_STATUS_OK) {
         return DCP_SYNC_FILTER_RESULT_ERROR;
     }
     questions = ldns_pkt_question(packet);
